@@ -13,3 +13,6 @@ REDIS_TYPE = {
 # redis列表和有序集的range边界
 LEFTMOST = 0
 RIGHTMOST = -1
+
+# 默认增量和减量
+DEFAULT_INCREMENT = DEFAULT_DECREMENT = 1
