@@ -10,7 +10,7 @@ class FloatTypeCase:
     """
 
     @staticmethod
-    def to_redis(value):
+    def encode(value):
         """
         接受 float 类型值，否则抛出 TypeError 。 
         """
@@ -20,7 +20,7 @@ class FloatTypeCase:
         raise TypeError
 
     @staticmethod
-    def to_python(value):
+    def decode(value):
         """ 
         尝试将值转换成 float 类型，
         如果转换失败，抛出 TypeError 。
