@@ -9,7 +9,7 @@ class JsonTypeCase:
     """
 
     @staticmethod
-    def to_redis(value):
+    def encode(value):
         """ 
         将值转成 JSON 对象，
         如果值不能转成 JSON 对象，抛出 TypeError 异常。
@@ -17,7 +17,7 @@ class JsonTypeCase:
         return json.dumps(value)
     
     @staticmethod
-    def to_python(value):
+    def decode(value):
         """ 
         将 Json 对象转回原来的类型。
         如果转换失败，抛出 TypeError 。
